@@ -41,6 +41,12 @@ class AuthenticationEnum(str, enum.Enum):
     custom = "custom"
 
 
+class AccessEnum(str, enum.Enum):
+    all = "all"
+    yaml = "yaml"
+    keycloak = "keycloak"
+
+
 class Base(pydantic.BaseModel):
     ...
 
@@ -121,7 +127,6 @@ class DefaultImages(Base):
     jupyterhub: str
     jupyterlab: str
     dask_worker: str
-    dask_gateway: str
 
 
 # =========== Authentication ==============
@@ -223,15 +228,39 @@ class NodeGroup(Base):
     min_nodes: int
     max_nodes: int
     gpu: typing.Optional[bool] = False
+    guest_accelerators: typing.Optional[typing.List[typing.Dict]] = []
 
     class Config:
         extra = "allow"
 
+    @validator("guest_accelerators")
+    def validate_guest_accelerators(cls, v):
+        if not v:
+            return v
+        if not isinstance(v, list):
+            raise ValueError("guest_accelerators must be a list")
+        for i in v:
+            assertion_error_message = """
+                In order to successfully use guest accelerators, you must specify the following parameters:
+
+                name (str): Machine type name of the GPU, available at https://cloud.google.com/compute/docs/gpus
+                count (int): Number of GPUs to attach to the instance
+
+                See general information regarding GPU support at:
+                https://docs.qhub.dev/en/stable/source/admin_guide/gpu.html?#add-gpu-node-group
+            """
+            try:
+                assert "name" in i and "count" in i
+                assert isinstance(i["name"], str) and isinstance(i["count"], int)
+            except AssertionError:
+                raise ValueError(assertion_error_message)
+
 
 class DigitalOceanProvider(Base):
     region: str
     kubernetes_version: str
     node_groups: typing.Dict[str, NodeGroup]
+    terraform_overrides: typing.Any
 
 
 class GoogleCloudPlatformProvider(Base):
@@ -241,6 +270,7 @@ class GoogleCloudPlatformProvider(Base):
     availability_zones: typing.Optional[typing.List[str]]  # Genuinely optional
     kubernetes_version: str
     node_groups: typing.Dict[str, NodeGroup]
+    terraform_overrides: typing.Any
 
 
 class AzureProvider(Base):
@@ -248,6 +278,7 @@ class AzureProvider(Base):
     kubernetes_version: str
     node_groups: typing.Dict[str, NodeGroup]
     storage_account_postfix: str
+    terraform_overrides: typing.Any
 
 
 class AmazonWebServicesProvider(Base):
@@ -255,6 +286,7 @@ class AmazonWebServicesProvider(Base):
     availability_zones: typing.Optional[typing.List[str]]
     kubernetes_version: str
     node_groups: typing.Dict[str, NodeGroup]
+    terraform_overrides: typing.Any
 
 
 class LocalProvider(Base):
@@ -291,6 +323,7 @@ class KubeSpawner(Base):
 
 
 class JupyterLabProfile(Base):
+    access: AccessEnum = AccessEnum.all
     display_name: str
     description: str
     default: typing.Optional[bool]
@@ -298,6 +331,18 @@ class JupyterLabProfile(Base):
     groups: typing.Optional[typing.List[str]]
     kubespawner_override: typing.Optional[KubeSpawner]
 
+    @root_validator
+    def only_yaml_can_have_groups_and_users(cls, values):
+        if values["access"] != AccessEnum.yaml:
+            if (
+                values.get("users", None) is not None
+                or values.get("groups", None) is not None
+            ):
+                raise ValueError(
+                    "Profile must not contain groups or users fields unless access = yaml"
+                )
+        return values
+
 
 class DaskWorkerProfile(Base):
     worker_cores_limit: int
@@ -314,7 +359,7 @@ class Profiles(Base):
     jupyterlab: typing.List[JupyterLabProfile]
     dask_worker: typing.Dict[str, DaskWorkerProfile]
 
-    @validator("jupyterlab", pre=True)
+    @validator("jupyterlab")
     def check_default(cls, v, values):
         """Check if only one default value is present"""
         default = [attrs["default"] for attrs in v if "default" in attrs]
@@ -364,6 +409,10 @@ class QHubExtension(Base):
     envs: typing.Optional[typing.List[QHubExtensionEnv]]
 
 
+class Ingress(Base):
+    terraform_overrides: typing.Any
+
+
 # ======== External Container Registry ========
 
 # This allows the user to set a private AWS ECR as a replacement for
@@ -402,14 +451,13 @@ class ExtContainerReg(Base):
 
 
 # ==================== Main ===================
-
 letter_dash_underscore_pydantic = pydantic.constr(regex=namestr_regex)
 
 
 class Main(Base):
-    project_name: letter_dash_underscore_pydantic
-    namespace: typing.Optional[letter_dash_underscore_pydantic]
     provider: ProviderEnum
+    project_name: str
+    namespace: typing.Optional[letter_dash_underscore_pydantic]
     qhub_version: str = ""
     ci_cd: typing.Optional[CICD]
     domain: str
@@ -437,6 +485,7 @@ class Main(Base):
     prevent_deploy: bool = (
         False  # Optional, but will be given default value if not present
     )
+    ingress: typing.Optional[Ingress]
 
     # If the qhub_version in the schema is old
     # we must tell the user to first run qhub upgrade
@@ -458,6 +507,45 @@ class Main(Base):
     def is_version_accepted(cls, v):
         return v != "" and rounded_ver_parse(v) == rounded_ver_parse(__version__)
 
+    @validator("project_name")
+    def project_name_convention(cls, value: typing.Any, values):
+        convention = """
+        In order to successfully deploy QHub, there are some project naming conventions which need
+        to be followed. First, ensure your name is compatible with the specific one for
+        your chosen Cloud provider. In addition, the QHub project name should also obey the following
+        format requirements:
+        - Letters from A to Z (upper and lower case) and numbers;
+        - Maximum accepted length of the name string is 16 characters.
+        - If using AWS: names should not start with the string "aws";
+        - If using Azure: names should not contain "-".
+        """
+        if len(value) > 16:
+            raise ValueError(
+                "\n".join(
+                    [
+                        convention,
+                        "Maximum accepted length of the project name string is 16 characters.",
+                    ]
+                )
+            )
+        elif values["provider"] == "azure" and ("-" in value):
+            raise ValueError(
+                "\n".join(
+                    [convention, "Provider [azure] does not allow '-' in project name."]
+                )
+            )
+        elif values["provider"] == "aws" and value.startswith("aws"):
+            raise ValueError(
+                "\n".join(
+                    [
+                        convention,
+                        "Provider [aws] does not allow 'aws' as starting sequence in project name.",
+                    ]
+                )
+            )
+        else:
+            return letter_dash_underscore_pydantic
+
 
 def verify(config):
     return Main(**config)
